@@ -73,7 +73,7 @@ void ePerl_SetScalar(char *pname, char *vname, char *vvalue)
  */
 void ePerl_ForceUnbufferedStdout(void)
 {
-    perl_eval_sv(newSVpv("$| = 1;",0), G_DISCARD);
+    IoFLAGS(GvIOp(defoutgv)) |= IOf_FLUSH; /* $|=1 */
     return;
 }
 
